import os

BASE_DIR = os.path.abspath(os.path.dirname(__file__))
BASE_DIR = BASE_DIR.replace('\\', '/')

CADDY_RUNTIME_DIR = BASE_DIR
CADDY_RUNTIME_NAME = 'caddy'
CADDY_RUNTIME_PATH = BASE_DIR + '/' + CADDY_RUNTIME_NAME
